#
# spec file for package python-reportlab
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define modname reportlab
Name:           python-%{modname}
Version:        2.7
Release:        6.2
Url:            http://www.reportlab.com/
Summary:        The Reportlab Toolkit
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://www.reportlab.com/ftp/%{modname}-%{version}.tar.gz
Patch0:         reportlab-missing-includes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  freetype2-devel
BuildRequires:  python-devel
BuildRequires:  python-imaging
BuildRequires:  python-xml
Requires:       python-imaging
Provides:       python-ReportLab = %{version}
Obsoletes:      python-ReportLab < %{version}
%if 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%else
%py_requires
%endif

%description
The ReportLab Toolkit. An Open Source Python library for generating PDFs and graphics.

%prep
%setup -q -n %{modname}-%{version}
%patch0
sed -i "1d" src/reportlab/lib/{formatters,fonts,set_ops,corp,units,pagesizes,__init__,randomtext,logger,normalDate}.py
sed -i "1d" src/reportlab/graphics/{widgets/table,barcode/test,testdrawings,testshapes}.py # Fix non-executable bits

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python setup.py tests

%files
%defattr(-,root,root,-)
%doc CHANGES.txt README.txt
%{python_sitearch}/_renderPM.so
%{python_sitearch}/_rl_accel.so
%{python_sitearch}/pyHnj.so
%{python_sitearch}/sgmlop.so
%{python_sitearch}/%{modname}/
%{python_sitearch}/%{modname}-%{version}-py%{py_ver}.egg-info

%changelog
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 2.7
  + No relative ChangeLog entry
* Thu Jan 24 2013 p.drouand@gmail.com
- Update to version 2.6:
  * General changes
  - Manuals have been reformatted with more pleasing code snippets and tables of
    contents, and reviewed and expanded
  * Flowing documents (Platypus):
  - Added support for HTML-style list objects
  - Added flexible mechanism for drawing bullets
  - Allowed XPreformatted objects to use Asian line wrapping
  - Added an 'autoNextPageTemplate' attribute to PageTemplates.  For example you
    can now set up a 'chapter first page template' which will always be followed
    by a 'continuation template' on the next page break, saving the programmer from
    having to issue control flow commands in the story.
  - added a TopPadder flowable, which will 'wrap' another Flowable and move it
    to the bottom of the current page.
  - More helpful error messages when large tables cannot be rendered
  - Documentation for images within text (test_032_images)
  - Trailing dots for use on contents pages
  * Charts and graphics:
  - Support for UPCA bar codes
  - We now have a semi-intelligent system for labelling pie charts with
    callout lines.  Thanks to James Martin-Collar, a maths student at Warwick
    University, who did this as his summer internship.
  - Axes - added startOffset and endOffset properties; allowed for axis
    background annotations.
  - Bar charts - allow more control of z Index (i.e. drawing order of axes and
    lines)
  - Pie charts - fixed bugs in 3d appearance
  - SVG output back end has seen some bugs fixed and now outputs resizeable SVG
* Fri May 25 2012 toddrme2178@gmail.com
- Clean up spec file
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Sep 20 2011 saschpe@suse.de
- Fix non-executable bit rpmlint warning
* Mon May 30 2011 alexandre@exatati.com.br
- Add Provides and Obsoletes to python-ReportLab in spec file to
  better behaviour in 11.1.
* Tue Apr 12 2011 alexandre@exatati.com.br
- Update to 2.5:
  - Please readme CHANGES.txt.
- Regenerate spec file with py2pack;
- Add CHANGES.txt and README.txt files as documentation;
- Bzip2 source code.
* Thu Jan 21 2010 alexandre@exatati.com.br
- Update to 2.4.
* Mon Dec 28 2009 alexandre@exatati.com.br
- New ReportLab package (2.3) for openSUSE, now in d:l:py.
